from distutils.core import setup

setup(
    name            = 'nester_peridot',
    version         = '1.4.0',
    py_modules      = ['nester'],
    author          = 'Peridot',
    author_email    = 'leeokmin@gmail.com',
    url             = 'NULL',
    description     = 'A simple printer of nested lists',
)
